@@ -1,5 +1,5 @@
 Vue.component("colors", {
-  template: `<span v-bind:id="jp_props.id"></span>`,
+  template: `<span v-bind:id="jp_props.id" style="display:none"></span>`,
   mounted() {
     var colors = this.$props.jp_props.options;
     for (var color in colors) {
