@@ -1,16 +1,13 @@
+from typing import Callable, Optional
+
 import justpy as jp
-from typing import Awaitable, Callable, Optional, Union
+
 from .value_element import ValueElement
 
+
 class FloatElement(ValueElement):
 
-    def __init__(self,
-                 view: jp.HTMLBaseComponent,
-                 *,
-                 value: float,
-                 format: str = None,
-                 on_change: Optional[Union[Callable, Awaitable]],
-                 ):
+    def __init__(self, view: jp.HTMLBaseComponent, *, value: float, format: str = None, on_change: Optional[Callable]):
         self.format = format
 
         super().__init__(view, value=value, on_change=on_change)
