@@ -1,60 +1,67 @@
+import asyncio
 import traceback
+from dataclasses import dataclass
 from inspect import signature
 from typing import Any, Callable, List, Optional
 
-from justpy.htmlcomponents import HTMLBaseComponent
-from pydantic import BaseModel
 from starlette.websockets import WebSocket
 
 from .elements.element import Element
 from .helpers import is_coroutine
+from .lifecycle import on_startup
 from .task_logger import create_task
 
 
-class EventArguments(BaseModel):
-    class Config:
-        arbitrary_types_allowed = True
+@dataclass
+class EventArguments:
     sender: Element
     socket: Optional[WebSocket]
 
 
+@dataclass
 class ClickEventArguments(EventArguments):
     pass
 
 
+@dataclass
 class ColorPickEventArguments(EventArguments):
     color: str
 
 
+@dataclass
 class MouseEventArguments(EventArguments):
     type: str
     image_x: float
     image_y: float
 
 
+@dataclass
 class UploadEventArguments(EventArguments):
     files: List[bytes]
 
 
+@dataclass
 class ValueChangeEventArguments(EventArguments):
     value: Any
 
 
-class KeyboardAction(BaseModel):
-    keypress: bool
+@dataclass
+class KeyboardAction:
     keydown: bool
     keyup: bool
     repeat: bool
 
 
-class KeyboardModifiers(BaseModel):
+@dataclass
+class KeyboardModifiers:
     alt: bool
     ctrl: bool
     meta: bool
     shift: bool
 
 
-class KeyboardKey(BaseModel):
+@dataclass
+class KeyboardKey:
     name: str
     code: str
     location: int
@@ -211,32 +218,24 @@ class KeyboardKey(BaseModel):
         return self.name == 'F12'
 
 
+@dataclass
 class KeyEventArguments(EventArguments):
-    class Config:
-        arbitrary_types_allowed = True
     action: KeyboardAction
     key: KeyboardKey
     modifiers: KeyboardModifiers
 
 
-def handle_event(handler: Optional[Callable], arguments: EventArguments, *,
-                 update: Optional[HTMLBaseComponent] = None) -> Optional[bool]:
+def handle_event(handler: Optional[Callable], arguments: EventArguments) -> Optional[bool]:
     try:
         if handler is None:
             return False
         no_arguments = not signature(handler).parameters
         result = handler() if no_arguments else handler(arguments)
         if is_coroutine(handler):
-            async def async_handler():
-                try:
-                    await result
-                    if update is not None:
-                        await update.update()
-                except Exception:
-                    traceback.print_exc()
-            create_task(async_handler(), name=str(handler))
-            return False
-        else:
-            return False if result == False else None
+            if asyncio.get_event_loop().is_running():
+                create_task(result, name=str(handler))
+            else:
+                on_startup(None, result)
+        return False
     except Exception:
         traceback.print_exc()
