@@ -25,7 +25,7 @@ class Timer:
         A timer will execute a callback repeatedly with a given interval.
 
         :param interval: the interval in which the timer is called (can be changed during runtime)
-        :param callback: function or coroutine to execute when interval elapses (can return `False` to prevent view update)
+        :param callback: function or coroutine to execute when interval elapses
         :param active: whether the callback should be executed or not (can be changed during runtime)
         :param once: whether the callback is only executed once after a delay specified by `interval` (default: `False`)
         """
